==> qtjambi-qt3dinput-5.15.13-sources.jar: io/qt/qt3d/input/QKeyboardDevice.java <==
package io.qt.qt3d.input;


/**
 * <p>In charge of dispatching keyboard events to attached QQKeyboardHandler objects</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dinput-qkeyboarddevice.html">Qt3DInput::QKeyboardDevice</a></p>
 */
public class QKeyboardDevice extends io.qt.qt3d.input.QAbstractPhysicalDevice
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QKeyboardDevice.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qkeyboarddevice.html#activeInput-prop">Qt3DInput::QKeyboardDevice::activeInputChanged(Qt3DInput::QKeyboardHandler*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="activeInput")
    public final Signal1<io.qt.qt3d.input.QKeyboardHandler> activeInputChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QKeyboardDevice(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QKeyboardDevice() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qkeyboarddevice.html#QKeyboardDevice">Qt3DInput::QKeyboardDevice::QKeyboardDevice(QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QKeyboardDevice(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QKeyboardDevice instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qkeyboarddevice.html#activeInput-prop">Qt3DInput::QKeyboardDevice::activeInput()const</a></p>
     */
    @io.qt.QtPropertyReader(name="activeInput")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.input.QKeyboardHandler activeInput(){
        return activeInput_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.input.QKeyboardHandler activeInput_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qabstractphysicaldevice.html#axisCount">Qt3DInput::QAbstractPhysicalDevice::axisCount()const</a></p>
     */
    public final int axisCount(){
        return axisCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native int axisCount_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qabstractphysicaldevice.html#axisIdentifier">Qt3DInput::QAbstractPhysicalDevice::axisIdentifier(QString)const</a></p>
     */
    public final int axisIdentifier(java.lang.String name){
        return axisIdentifier_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    private native int axisIdentifier_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qabstractphysicaldevice.html#axisNames">Qt3DInput::QAbstractPhysicalDevice::axisNames()const</a></p>
     */
    public final io.qt.core.QStringList axisNames(){
        return axisNames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native io.qt.core.QStringList axisNames_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qabstractphysicaldevice.html#buttonCount">Qt3DInput::QAbstractPhysicalDevice::buttonCount()const</a></p>
     */
    public final int buttonCount(){
        return buttonCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native int buttonCount_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qabstractphysicaldevice.html#buttonIdentifier">Qt3DInput::QAbstractPhysicalDevice::buttonIdentifier(QString)const</a></p>
     */
    public final int buttonIdentifier(java.lang.String name){
        return buttonIdentifier_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    private native int buttonIdentifier_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qabstractphysicaldevice.html#buttonNames">Qt3DInput::QAbstractPhysicalDevice::buttonNames()const</a></p>
     */
    public final io.qt.core.QStringList buttonNames(){
        return buttonNames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native io.qt.core.QStringList buttonNames_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sceneChangeEvent">Qt3DCore::QNode::sceneChangeEvent(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @io.qt.QtUninvokable
    protected void sceneChangeEvent(io.qt.qt3d.core.QSceneChange change){
        sceneChangeEvent_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @io.qt.QtUninvokable
    private native void sceneChangeEvent_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QKeyboardDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QKeyboardDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QKeyboardDevice instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dinput-6.2.3-sources.jar: io/qt/qt3d/input/QKeyboardDevice.java <==
package io.qt.qt3d.input;


/**
 * <p>In charge of dispatching keyboard events to attached QQKeyboardHandler objects</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3dinput-qkeyboarddevice.html">Qt3DInput::QKeyboardDevice</a></p>
 */
public class QKeyboardDevice extends io.qt.qt3d.input.QAbstractPhysicalDevice
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QKeyboardDevice.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qkeyboarddevice.html#activeInput-prop">Qt3DInput::QKeyboardDevice::activeInputChanged(Qt3DInput::QKeyboardHandler*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="activeInput")
    public final Signal1<io.qt.qt3d.input.QKeyboardHandler> activeInputChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QKeyboardDevice(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QKeyboardDevice() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qkeyboarddevice.html#QKeyboardDevice">Qt3DInput::QKeyboardDevice::QKeyboardDevice(Qt3DInput::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QKeyboardDevice(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QKeyboardDevice instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qkeyboarddevice.html#activeInput-prop">Qt3DInput::QKeyboardDevice::activeInput()const</a></p>
     */
    @io.qt.QtPropertyReader(name="activeInput")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.input.QKeyboardHandler activeInput(){
        return activeInput_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.input.QKeyboardHandler activeInput_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qabstractphysicaldevice.html#axisCount">Qt3DInput::QAbstractPhysicalDevice::axisCount()const</a></p>
     */
    public final int axisCount(){
        return axisCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native int axisCount_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qabstractphysicaldevice.html#axisIdentifier">Qt3DInput::QAbstractPhysicalDevice::axisIdentifier(QString)const</a></p>
     */
    public final int axisIdentifier(java.lang.String name){
        return axisIdentifier_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    private native int axisIdentifier_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qabstractphysicaldevice.html#axisNames">Qt3DInput::QAbstractPhysicalDevice::axisNames()const</a></p>
     */
    public final io.qt.core.QStringList axisNames(){
        return axisNames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native io.qt.core.QStringList axisNames_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qabstractphysicaldevice.html#buttonCount">Qt3DInput::QAbstractPhysicalDevice::buttonCount()const</a></p>
     */
    public final int buttonCount(){
        return buttonCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native int buttonCount_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qabstractphysicaldevice.html#buttonIdentifier">Qt3DInput::QAbstractPhysicalDevice::buttonIdentifier(QString)const</a></p>
     */
    public final int buttonIdentifier(java.lang.String name){
        return buttonIdentifier_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    private native int buttonIdentifier_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qabstractphysicaldevice.html#buttonNames">Qt3DInput::QAbstractPhysicalDevice::buttonNames()const</a></p>
     */
    public final io.qt.core.QStringList buttonNames(){
        return buttonNames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native io.qt.core.QStringList buttonNames_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QKeyboardDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QKeyboardDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QKeyboardDevice instance, QDeclarativeConstructor constructor);
    
}
